aboutsummaryrefslogtreecommitdiffstats
path: root/OpenAL32/Include/alMain.h
diff options
context:
space:
mode:
Diffstat (limited to 'OpenAL32/Include/alMain.h')
-rw-r--r--OpenAL32/Include/alMain.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/OpenAL32/Include/alMain.h b/OpenAL32/Include/alMain.h
index 34722d98..6a0df589 100644
--- a/OpenAL32/Include/alMain.h
+++ b/OpenAL32/Include/alMain.h
@@ -549,8 +549,8 @@ enum DevFmtChannels {
DevFmtX61 = ALC_6POINT1_SOFT,
DevFmtX71 = ALC_7POINT1_SOFT,
- /* Similar to 5.1, except using the side channels instead of back */
- DevFmtX51Side = 0x80000000,
+ /* Similar to 5.1, except using rear channels instead of sides */
+ DevFmtX51Rear = 0x80000000,
DevFmtChannelsDefault = DevFmtStereo
};